#######################
PyDMNTTable
#######################

.. autoclass:: pydm.widgets.nt_table.PythonTableModel
   :members:
   :show-inheritance:

.. autoclass:: pydm.widgets.nt_table.PyDMNTTable
   :members:
   :show-inheritance: